@@ -30,7 +30,7 @@ opts_chunk$set(fig.width=5.0,fig.height=3.0,out.width="5in",out.height="3in",dpi
 options(width=64,digits=2)
 #opts_chunk$set(size="tiny")
 opts_chunk$set(size="small")
-opts_chunk$set(tidy=TRUE,tidy.opts=list(width.cutoff=36,keep.blank.line=TRUE))
+opts_chunk$set(tidy=TRUE,tidy.opts=list(width.cutoff=36,blank=TRUE))
 
 compile.time <- Sys.time()
 
@@ -73,13 +73,13 @@ testf <- function(dpqr,nobs,...) {
 		labs(title="Density (tests dfunc)")
 
 	# Q-Q plot
-	p2 <- ggplot(data, aes(sample = draws)) + stat_qq(dist=function(p) { dpqr$q(p,...) }) +
+	p2 <- ggplot(data, aes(sample = draws)) + stat_qq(distribution=function(p) { dpqr$q(p,...) }) +
 		geom_abline(slope=1,intercept=0,colour='red') + 
 		theme(text=element_text(size=text.size)) + 
 		labs(title="Q-Q plot (tests qfunc)")
 
 	# empirical CDF of the p-values; should be uniform
-	p3 <- ggplot(data, aes(sample = pvals)) + stat_qq(dist=qunif) + 
+	p3 <- ggplot(data, aes(sample = pvals)) + stat_qq(distribution=qunif) + 
 		geom_abline(slope=1,intercept=0,colour='red') + 
 		theme(text=element_text(size=text.size)) + 
 		labs(title="P-P plot (tests pfunc)")
